/*******************************************************************
*   SASload_KID_2003_HOSPITAL.SAS:                                
*      THE SAS CODE SHOWN BELOW WILL LOAD THE ASCII                 
*      HOSPITAL FILE INTO SAS                                         
*******************************************************************/


***********************************************;
*  Create SAS informats for missing values     ;
***********************************************;
PROC FORMAT;
  INVALUE N2PF
    '-9' = .
    '-8' = .A
    '-6' = .C
    '-5' = .N
    OTHER = (|2.|)
  ;
  INVALUE N3PF
    '-99' = .
    '-88' = .A
    '-66' = .C
    OTHER = (|3.|)
  ;
  INVALUE N4PF
    '-999' = .
    '-888' = .A
    '-666' = .C
    OTHER = (|4.|)
  ;
  INVALUE N5PF
    '-9999' = .
    '-8888' = .A
    '-6666' = .C
    OTHER = (|5.|)
  ;
  INVALUE N5P2F
    '-9.99' = .
    '-8.88' = .A
    '-6.66' = .C
    OTHER = (|5.2|)
  ;
  INVALUE N6PF
    '-99999' = .
    '-88888' = .A
    '-66666' = .C
    OTHER = (|6.|)
  ;
  INVALUE N6P2F
    '-99.99' = .
    '-88.88' = .A
    '-66.66' = .C
    OTHER = (|6.2|)
  ;
  INVALUE N7P2F
    '-999.99' = .
    '-888.88' = .A
    '-666.66' = .C
    OTHER = (|7.2|)
  ;
  INVALUE N8PF
    '-9999999' = .
    '-8888888' = .A
    '-6666666' = .C
    OTHER = (|8.|)
  ;
  INVALUE N8P2F
    '-9999.99' = .
    '-8888.88' = .A
    '-6666.66' = .C
    OTHER = (|8.2|)
  ;
  INVALUE N8P4F
    '-99.9999' = .
    '-88.8888' = .A
    '-66.6666' = .C
    OTHER = (|8.4|)
  ;
  INVALUE N10PF
    '-999999999' = .
    '-888888888' = .A
    '-666666666' = .C
    OTHER = (|10.|)
  ;
  INVALUE N10P4F
    '-9999.9999' = .
    '-8888.8888' = .A
    '-6666.6666' = .C
    OTHER = (|10.4|)
  ;
  INVALUE N10P5F
    '-999.99999' = .
    '-888.88888' = .A
    '-666.66666' = .C
    OTHER = (|10.5|)
  ;
  INVALUE DATE10F
    '-999999999' = .
    '-888888888' = .A
    '-666666666' = .C
    OTHER = (|MMDDYY10.|)
  ;
  INVALUE N11P7F
    '-99.9999999' = .
    '-88.8888888' = .A
    '-66.6666666' = .C
    OTHER = (|11.7|)
  ;
  INVALUE N12P2F
    '-99999999.99' = .
    '-88888888.88' = .A
    '-66666666.66' = .C
    OTHER = (|12.2|)
  ;
  INVALUE N12P5F
    '-99999.99999' = .
    '-88888.88888' = .A
    '-66666.66666' = .C
    OTHER = (|12.5|)
  ;
  INVALUE N15P2F
    '-99999999999.99' = .
    '-88888888888.88' = .A
    '-66666666666.66' = .C
    OTHER = (|15.2|)
  ;
  RUN;


*******************************;
*  Data Step                  *;
*******************************;
DATA KID_2003_HOSPITAL; 
INFILE 'KID_2003_HOSPITAL.ASC' LRECL = 204;                                                                                                                                                                                                    

*** Variable attribute ***;
ATTRIB 
  AHAID                      LENGTH=$7
  LABEL="AHA hospital identifier"

  HOSPADDR                   LENGTH=$30
  LABEL="Hospital address from AHA Survey (Z011)"

  HOSPCITY                   LENGTH=$20
  LABEL="Hospital city from AHA Survey (Z012)"

  HOSPID                     LENGTH=4            FORMAT=Z5.
  LABEL="HCUP hospital identification number"

  HOSPNAME                   LENGTH=$30
  LABEL="Hospital name from AHA Survey (Z000)"

  HOSPST                     LENGTH=$2
  LABEL="Hospital state postal code"

  HOSPSTCO                   LENGTH=4
  LABEL="Hospital modified FIPS state/county code"

  HOSPZIP                    LENGTH=$5
  LABEL="Hospital ZIP Code from AHA Survey (Z014)"

  HOSP_BEDSIZE               LENGTH=3            FORMAT=2.
  LABEL="Bedsize of hospital"

  HOSP_CONTROL               LENGTH=3            FORMAT=2.
  LABEL="Control/ownership of hospital"

  HOSP_LOCATION              LENGTH=3            FORMAT=2.
  LABEL="Location (urban/rural) of hospital"

  HOSP_LOCTEACH              LENGTH=3            FORMAT=2.
  LABEL="Location/teaching status of hospital"

  HOSP_REGION                LENGTH=3            FORMAT=2.
  LABEL="Region of hospital"

  HOSP_TEACH                 LENGTH=3            FORMAT=2.
  LABEL="Teaching status of hospital"

  IDNUMBER                   LENGTH=$6
  LABEL="AHA hospital identifier without the leading 6"

  KID_STRATUM                LENGTH=4
  LABEL="Hospital stratum used for weights"

  NACHTYPE                   LENGTH=3
  LABEL="NACHRI hospital type"

  N_BRTH_U                   LENGTH=8
  LABEL="Number of universe births in KID_STRATUM"

  N_DISC_U                   LENGTH=8
  LABEL="Number of universe discharges in KID_STRATUM"

  N_HOSP_U                   LENGTH=8
  LABEL="Number of universe hospitals in KID_STRATUM"

  PEDS_DISC                  LENGTH=4
  LABEL="Number of discharges, 20 years old or younger, from this hospital in the SID"

  PEDS_PCT                   LENGTH=8
  LABEL="Percentage of hospital discharges, 20 years old or younger"

  S_BRTH_U                   LENGTH=8
  LABEL="Number of sample births in KID_STRATUM"

  S_CHLD_U                   LENGTH=8
  LABEL="Number of sample pediatric non-births in KID_STRATUM"

  S_CMPB_U                   LENGTH=8
  LABEL="Number of sample complicated births in KID_STRATUM"

  S_DISC_U                   LENGTH=8
  LABEL="Number of sample births and children in KID_STRATUM"

  S_HOSP_U                   LENGTH=8
  LABEL="Number of sample hospitals in KID_STRATUM"

  S_UNCB_U                   LENGTH=8
  LABEL="Number of sample uncomplicated births in KID_STRATUM"

  TOTAL_DISC                 LENGTH=4
  LABEL="Total number of discharges from this hospital in the SID"

  YEAR                       LENGTH=3
  LABEL="Calendar year"
  ;


*** Input the variables from the ASCII file ***;
INPUT 
      @1      AHAID                    $CHAR7.
      @8      HOSPADDR                 $CHAR30.
      @38     HOSPCITY                 $CHAR20.
      @58     HOSPID                   5.
      @63     HOSPNAME                 $CHAR30.
      @93     HOSPST                   $CHAR2.
      @95     HOSPSTCO                 N5PF.
      @100    HOSPZIP                  $CHAR5.
      @105    HOSP_BEDSIZE             N2PF.
      @107    HOSP_CONTROL             N2PF.
      @109    HOSP_LOCATION            N2PF.
      @111    HOSP_LOCTEACH            N2PF.
      @113    HOSP_REGION              N2PF.
      @115    HOSP_TEACH               N2PF.
      @117    IDNUMBER                 $CHAR6.
      @123    KID_STRATUM              N4PF.
      @127    NACHTYPE                 N2PF.
      @129    N_BRTH_U                 N6PF.
      @135    N_DISC_U                 N8PF.
      @143    N_HOSP_U                 N4PF.
      @147    PEDS_DISC                N6PF.
      @153    PEDS_PCT                 N8P4F.
      @161    S_BRTH_U                 N6PF.
      @167    S_CHLD_U                 N6PF.
      @173    S_CMPB_U                 N6PF.
      @179    S_DISC_U                 N6PF.
      @185    S_HOSP_U                 N4PF.
      @189    S_UNCB_U                 N6PF.
      @195    TOTAL_DISC               N6PF.
      @201    YEAR                     N4PF.
      ;


RUN;
